@@ -201,12 +201,12 @@ class FastScanCommand:
         while True:
             if self.stopped.is_set():
                 return
-            self._detectorAcquisitions += (time.time(), self._controller.adc.read())
+            self._detectorAcquisitions.append((time.time(), self._controller.adc.read()))
             if self.stopped.wait(0.001):
                 return
 
     def record_callback(self, x, y, t):
-        self._vcmAcquisitions += (t, x, y)
+        self._vcmAcquisitions.append((t, x, y))
 
     def clear_registers(self):
         self._detectorAcquisitions = []
